---
title: <span class="badge builder"></span> StackingConfig
---
# <span class="badge builder"></span> StackingConfig

## Constructor

```python
StackingConfig()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.StackingConfig
```

### <span class="badge object-method"></span> group

```python
def group(group: str) -> typing.Self
```

### <span class="badge object-method"></span> mode

```python
def mode(mode: common.StackingMode) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [StackingConfig](./object-StackingConfig.md)
